@@ -1,10 +1,10 @@
 __author__ = 'Altertech, http://www.altertech.com/'
 __copyright__ = 'Copyright (C) 2018-2020 Altertech Group'
 __license__ = 'Apache License 2.0'
-__version__ = '2.0.25'
+__version__ = '2.0.27'
 
 from flask import request, jsonify, Response, abort
-from flask_restplus import Api, Resource, reqparse
+from flask_restx import Api, Resource, reqparse
 
 import simplejson
 
@@ -213,8 +213,7 @@ def init():
                             type=str)
         p_push.add_argument('expires',
                             default=None,
-                            help='reserved, don\'t use',
-                            type=int)
+                            help='reserved, don\'t use')
         p_push.add_argument('media',
                             default=None,
                             help='base64-encoded media file',
